==> kea-docs-2.2.0-2-x86_64.pkg.tar.zst: usr/share/doc/kea/devel/dir_31c7d756f07a362aee1b6bd4e4ec50f5.js <==
var dir_31c7d756f07a362aee1b6bd4e4ec50f5 =
[
    [ "callout_handle.cc", "d3/d6f/callout__handle_8cc.html", null ],
    [ "callout_handle.h", "d0/d60/callout__handle_8h.html", "d0/d60/callout__handle_8h" ],
    [ "callout_handle_associate.cc", "dc/d81/callout__handle__associate_8cc.html", null ],
    [ "callout_handle_associate.h", "db/d64/callout__handle__associate_8h.html", [
      [ "isc::hooks::CalloutHandleAssociate", "d8/d57/classisc_1_1hooks_1_1CalloutHandleAssociate.html", "d8/d57/classisc_1_1hooks_1_1CalloutHandleAssociate" ]
    ] ],
    [ "callout_manager.cc", "d8/da4/callout__manager_8cc.html", null ],
    [ "callout_manager.h", "dc/d1c/callout__manager_8h.html", [
      [ "isc::hooks::CalloutManager", "d4/d67/classisc_1_1hooks_1_1CalloutManager.html", "d4/d67/classisc_1_1hooks_1_1CalloutManager" ],
      [ "isc::hooks::NoSuchLibrary", "d1/dce/classisc_1_1hooks_1_1NoSuchLibrary.html", "d1/dce/classisc_1_1hooks_1_1NoSuchLibrary" ]
    ] ],
    [ "hooks.h", "d7/dff/hooks_8h.html", "d7/dff/hooks_8h" ],
    [ "hooks_config.cc", "d5/dea/hooks__config_8cc.html", null ],
    [ "hooks_config.h", "df/d5c/hooks__config_8h.html", [
      [ "isc::hooks::HooksConfig", "d0/d40/classisc_1_1hooks_1_1HooksConfig.html", "d0/d40/classisc_1_1hooks_1_1HooksConfig" ],
      [ "isc::hooks::InvalidHooksLibraries", "de/d4f/classisc_1_1hooks_1_1InvalidHooksLibraries.html", "de/d4f/classisc_1_1hooks_1_1InvalidHooksLibraries" ]
    ] ],
    [ "hooks_log.cc", "d5/ddd/hooks__log_8cc.html", "d5/ddd/hooks__log_8cc" ],
    [ "hooks_log.h", "de/da7/hooks__log_8h.html", null ],
    [ "hooks_manager.cc", "d9/da4/hooks__manager_8cc.html", null ],
    [ "hooks_manager.h", "df/df4/hooks__manager_8h.html", [
      [ "isc::hooks::HooksManager", "d4/d88/classisc_1_1hooks_1_1HooksManager.html", null ],
      [ "isc::hooks::LibrariesStillOpened", "d3/d6d/classisc_1_1hooks_1_1LibrariesStillOpened.html", "d3/d6d/classisc_1_1hooks_1_1LibrariesStillOpened" ]
    ] ],
    [ "hooks_messages.cc", "df/d53/hooks__messages_8cc.html", "df/d53/hooks__messages_8cc" ],
    [ "hooks_messages.h", "d3/dad/hooks__messages_8h.html", null ],
    [ "hooks_parser.cc", "d2/d17/hooks__parser_8cc.html", null ],
    [ "hooks_parser.h", "d7/d37/hooks__parser_8h.html", [
      [ "isc::hooks::HooksLibrariesParser", "d1/dc2/classisc_1_1hooks_1_1HooksLibrariesParser.html", "d1/dc2/classisc_1_1hooks_1_1HooksLibrariesParser" ]
    ] ],
    [ "libinfo.cc", "da/d86/libinfo_8cc.html", "da/d86/libinfo_8cc" ],
    [ "libinfo.h", "da/d2d/libinfo_8h.html", "da/d2d/libinfo_8h" ],
    [ "library_handle.cc", "da/dcb/library__handle_8cc.html", null ],
    [ "library_handle.h", "da/d4a/library__handle_8h.html", "da/d4a/library__handle_8h" ],
    [ "library_manager.cc", "d5/d28/library__manager_8cc.html", "d5/d28/library__manager_8cc" ],
    [ "library_manager.h", "d5/def/library__manager_8h.html", [
      [ "isc::hooks::LibraryManager", "d4/d98/classisc_1_1hooks_1_1LibraryManager.html", "d4/d98/classisc_1_1hooks_1_1LibraryManager" ],
      [ "isc::hooks::NoCalloutManager", "dc/d8b/classisc_1_1hooks_1_1NoCalloutManager.html", "dc/d8b/classisc_1_1hooks_1_1NoCalloutManager" ]
    ] ],
    [ "library_manager_collection.cc", "d1/d17/library__manager__collection_8cc.html", null ],
    [ "library_manager_collection.h", "d1/ddf/library__manager__collection_8h.html", [
      [ "isc::hooks::LibraryManagerCollection", "dc/d35/classisc_1_1hooks_1_1LibraryManagerCollection.html", "dc/d35/classisc_1_1hooks_1_1LibraryManagerCollection" ],
      [ "isc::hooks::LoadLibrariesNotCalled", "d2/d8d/classisc_1_1hooks_1_1LoadLibrariesNotCalled.html", "d2/d8d/classisc_1_1hooks_1_1LoadLibrariesNotCalled" ]
    ] ],
    [ "parking_lots.h", "d6/d02/parking__lots_8h.html", "d6/d02/parking__lots_8h" ],
    [ "pointer_converter.h", "d7/da3/pointer__converter_8h.html", [
      [ "isc::hooks::PointerConverter", "da/d42/classisc_1_1hooks_1_1PointerConverter.html", "da/d42/classisc_1_1hooks_1_1PointerConverter" ]
    ] ],
    [ "server_hooks.cc", "d8/dc7/server__hooks_8cc.html", null ],
    [ "server_hooks.h", "de/d2d/server__hooks_8h.html", "de/d2d/server__hooks_8h" ]
];

==> kea-docs-3.0.0-6-x86_64.pkg.tar.zst: usr/share/doc/kea/devel/dir_31c7d756f07a362aee1b6bd4e4ec50f5.js <==
var dir_31c7d756f07a362aee1b6bd4e4ec50f5 =
[
    [ "callout_handle.cc", "d3/d6f/callout__handle_8cc.html", null ],
    [ "callout_handle.h", "d0/d60/callout__handle_8h.html", "d0/d60/callout__handle_8h" ],
    [ "callout_handle_associate.cc", "dc/d81/callout__handle__associate_8cc.html", null ],
    [ "callout_handle_associate.h", "db/d64/callout__handle__associate_8h.html", "db/d64/callout__handle__associate_8h" ],
    [ "callout_manager.cc", "d8/da4/callout__manager_8cc.html", null ],
    [ "callout_manager.h", "dc/d1c/callout__manager_8h.html", "dc/d1c/callout__manager_8h" ],
    [ "hooks.h", "d7/dff/hooks_8h.html", "d7/dff/hooks_8h" ],
    [ "hooks_config.cc", "d5/dea/hooks__config_8cc.html", null ],
    [ "hooks_config.h", "df/d5c/hooks__config_8h.html", "df/d5c/hooks__config_8h" ],
    [ "hooks_log.cc", "d5/ddd/hooks__log_8cc.html", "d5/ddd/hooks__log_8cc" ],
    [ "hooks_log.h", "de/da7/hooks__log_8h.html", null ],
    [ "hooks_manager.cc", "d9/da4/hooks__manager_8cc.html", null ],
    [ "hooks_manager.h", "df/df4/hooks__manager_8h.html", "df/df4/hooks__manager_8h" ],
    [ "hooks_messages.cc", "df/d53/hooks__messages_8cc.html", "df/d53/hooks__messages_8cc" ],
    [ "hooks_messages.h", "d3/dad/hooks__messages_8h.html", null ],
    [ "hooks_parser.cc", "d2/d17/hooks__parser_8cc.html", null ],
    [ "hooks_parser.h", "d7/d37/hooks__parser_8h.html", "d7/d37/hooks__parser_8h" ],
    [ "libinfo.cc", "da/d86/libinfo_8cc.html", "da/d86/libinfo_8cc" ],
    [ "libinfo.h", "da/d2d/libinfo_8h.html", "da/d2d/libinfo_8h" ],
    [ "library_handle.cc", "da/dcb/library__handle_8cc.html", null ],
    [ "library_handle.h", "da/d4a/library__handle_8h.html", "da/d4a/library__handle_8h" ],
    [ "library_manager.cc", "d5/d28/library__manager_8cc.html", "d5/d28/library__manager_8cc" ],
    [ "library_manager.h", "d5/def/library__manager_8h.html", "d5/def/library__manager_8h" ],
    [ "library_manager_collection.cc", "d1/d17/library__manager__collection_8cc.html", null ],
    [ "library_manager_collection.h", "d1/ddf/library__manager__collection_8h.html", "d1/ddf/library__manager__collection_8h" ],
    [ "parking_lots.h", "d6/d02/parking__lots_8h.html", "d6/d02/parking__lots_8h" ],
    [ "pointer_converter.h", "d7/da3/pointer__converter_8h.html", "d7/da3/pointer__converter_8h" ],
    [ "server_hooks.cc", "d8/dc7/server__hooks_8cc.html", null ],
    [ "server_hooks.h", "de/d2d/server__hooks_8h.html", "de/d2d/server__hooks_8h" ]
];
